==> central-repository-3.62.0.zip: com/microej/wear/services/ComponentService.java <==
/*
 * Copyright 2024-2025 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.wear.services;

import com.microej.wear.components.Activity;
import com.microej.wear.components.ComplicationDataSource;
import com.microej.wear.components.Navigator;
import com.microej.wear.components.Watchface;

/**
 * This service allows Features to register activities, watchfaces and complication data sources.
 */
public interface ComponentService {

	/**
	 * Sets the navigator.
	 *
	 * @param navigator
	 *            the navigator.
	 */
	void setNavigator(Navigator navigator);

	/**
	 * Registers the given activity.
	 *
	 * @param activity
	 *            the activity to register.
	 */
	void registerActivity(Activity activity);

	/**
	 * Registers the given watchface.
	 *
	 * @param watchface
	 *            the watchface to register.
	 */
	void registerWatchface(Watchface watchface);

	/**
	 * Registers the given complication data source.
	 *
	 * @param source
	 *            the source to register.
	 */
	void registerComplicationDataSource(ComplicationDataSource source);

	/**
	 * Returns the navigator.
	 *
	 * @return the navigator.
	 */
	Navigator getNavigator();

	/**
	 * Returns an array containing all the activities.
	 *
	 * @return an array containing all the activities.
	 */
	Activity[] getActivities();

	/**
	 * Returns an array containing all the watchfaces.
	 *
	 * @return an array containing all the watchfaces.
	 */
	Watchface[] getWatchfaces();

	/**
	 * Returns an array containing all the complication data sources.
	 *
	 * @return an array containing all the complication data sources.
	 */
	ComplicationDataSource[] getComplicationDataSources();
}

==> central-repository-3.63.0.zip: com/microej/wear/services/ComponentService.java <==
/*
 * Copyright 2024-2025 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.wear.services;

import com.microej.wear.components.Activity;
import com.microej.wear.components.ComplicationDataSource;
import com.microej.wear.components.Navigator;
import com.microej.wear.components.Watchface;

/**
 * This service allows Features to register activities, watchfaces and complication data sources.
 */
public interface ComponentService {

	/**
	 * Sets the navigator.
	 *
	 * @param navigator
	 *            the navigator
	 */
	void setNavigator(Navigator navigator);

	/**
	 * Registers the given activity.
	 *
	 * @param activity
	 *            the activity to register
	 */
	void registerActivity(Activity activity);

	/**
	 * Registers the given watchface.
	 *
	 * @param watchface
	 *            the watchface to register
	 */
	void registerWatchface(Watchface watchface);

	/**
	 * Registers the given complication data source.
	 *
	 * @param source
	 *            the source to register
	 */
	void registerComplicationDataSource(ComplicationDataSource source);

	/**
	 * Returns the navigator.
	 *
	 * @return the navigator
	 */
	Navigator getNavigator();

	/**
	 * Returns an array containing all the activities.
	 *
	 * @return an array containing all the activities
	 */
	Activity[] getActivities();

	/**
	 * Returns an array containing all the watchfaces.
	 *
	 * @return an array containing all the watchfaces
	 */
	Watchface[] getWatchfaces();

	/**
	 * Returns an array containing all the complication data sources.
	 *
	 * @return an array containing all the complication data sources
	 */
	ComplicationDataSource[] getComplicationDataSources();
}
